@@ -35,6 +35,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "yubikeyutil.h"
 #include "common.h"
 
+#include <QSettings>
+#include <QDateTime>
+#include <QDebug>
+#include <QSignalMapper>
+#include <QTableWidgetItem>
+
 ChalRespPage::ChalRespPage(QWidget *parent) :
         QStackedWidget(parent),
         ui(new Ui::ChalRespPage)
@@ -466,7 +472,7 @@ void ChalRespPage::changeQuickConfigParams() {
 bool ChalRespPage::validateQuickSettings() {
     if(!(ui->quickConfigSlot1Radio->isChecked() ||
          ui->quickConfigSlot2Radio->isChecked())) {
-        emit showStatusMessage(ERR_CONF_SLOT_NOT_SELECTED, 1);
+        emit showStatusMessage(tr(ERR_CONF_SLOT_NOT_SELECTED), 1);
         return false;
     }
 
@@ -570,14 +576,14 @@ void ChalRespPage::quickConfigWritten(bool written, const QString &msg) {
         m_keysProgrammedCtr++;
 
         if(m_state == State_Programming){
-            message = KEY_CONFIGURED.arg("");
+            message = tr(KEY_CONFIGURED).arg("");
         } else {
-            message = tr("%1. %2").arg(KEY_CONFIGURED.arg(m_keysProgrammedCtr)).arg(REMOVE_KEY);
+            message = tr("%1. %2").arg(tr(KEY_CONFIGURED).arg(m_keysProgrammedCtr)).arg(tr(REMOVE_KEY));
         }
 
         showStatusMessage(message, 0);
 
-        message = KEY_CONFIGURED.arg("");
+        message = tr(KEY_CONFIGURED).arg("");
     } else {
         qDebug() << "Configuration could not be written....";
 
@@ -599,7 +605,7 @@ void ChalRespPage::quickConfigExported(bool written, const QString &msg) {
     if(written) {
         qDebug() << "Configuration exported....";
 
-        message = KEY_EXPORTED;
+        message = tr(KEY_EXPORTED);
 
         showStatusMessage(message, 0);
     } else {
@@ -791,7 +797,7 @@ void ChalRespPage::changeAdvConfigParams() {
 bool ChalRespPage::validateAdvSettings() {
     if(!(ui->advConfigSlot1Radio->isChecked() ||
          ui->advConfigSlot2Radio->isChecked())) {
-        emit showStatusMessage(ERR_CONF_SLOT_NOT_SELECTED, 1);
+        emit showStatusMessage(tr(ERR_CONF_SLOT_NOT_SELECTED), 1);
         return false;
     }
 
@@ -890,14 +896,14 @@ void ChalRespPage::advConfigWritten(bool written, const QString &msg) {
         m_keysProgrammedCtr++;
 
         if(m_state == State_Programming){
-            message = KEY_CONFIGURED.arg("");
+            message = tr(KEY_CONFIGURED).arg("");
         } else {
-            message = tr("%1. %2").arg(KEY_CONFIGURED.arg(m_keysProgrammedCtr)).arg(REMOVE_KEY);
+            message = tr("%1. %2").arg(tr(KEY_CONFIGURED).arg(m_keysProgrammedCtr)).arg(tr(REMOVE_KEY));
         }
 
         showStatusMessage(message, 0);
 
-        message = KEY_CONFIGURED.arg("");
+        message = tr(KEY_CONFIGURED).arg("");
     } else {
         qDebug() << "Configuration could not be written....";
 
@@ -919,7 +925,7 @@ void ChalRespPage::advConfigExported(bool written, const QString &msg) {
     if(written) {
         qDebug() << "Configuration written....";
 
-        message = KEY_EXPORTED;
+        message = tr(KEY_EXPORTED);
 
         showStatusMessage(message, 0);
     } else {
