@@ -31,6 +31,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <QStackedWidget>
 #include "yubikeyconfig.h"
+#include "scanedit.h"
 
 namespace Ui {
     class StaticPage;
@@ -68,6 +69,8 @@ private:
 
     bool m_keyPresent;
 
+    ScanEdit *scanedit;
+
 public slots:
     void loadSettings();
     void setCurrentPage(int pageIndex);
