@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2011-2013 Yubico AB.  All rights reserved.
+Copyright (C) 2011-2014 Yubico AB.  All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are
@@ -71,7 +71,6 @@ public slots:
 private slots:
     void connectPages();
     void connectHelpButtons();
-    void helpBtn_pressed(int helpIndex);
 
     // Converter Page
     void resetConverterPage();
@@ -113,6 +112,7 @@ signals:
     void showStatusMessage(const QString &text, int status = 0);
     void reloadSettings();
     void switchPage(int page, int tab, int slot);
+    void showHelp(int helpIndex);
 };
 
 #endif // TOOLPAGE_H
