@@ -35,6 +35,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <ykdef.h>
 
 #include <QFileDialog>
+#include <QDebug>
+#include <QSettings>
 
 #define EXPORT_FILENAME_DEF "export.ycfg"
 
@@ -78,10 +80,10 @@ QString YubiKeyWriter::reportError(bool chalresp = false) {
         switch(ykp_errno) {
         case YKP_EYUBIKEYVER:
         case YKP_EOLDYUBIKEY:
-            errMsg = ERR_FEATURE_NOT_SUPPORTED;
+            errMsg = tr(ERR_FEATURE_NOT_SUPPORTED);
             break;
         default:
-            errMsg = ERR_PROCESSING;
+            errMsg = tr(ERR_PROCESSING);
             break;
         }
         ykp_errno = 0;
@@ -96,16 +98,16 @@ QString YubiKeyWriter::reportError(bool chalresp = false) {
 
         switch(yk_errno) {
         case YK_ENOKEY:
-            errMsg = ERR_KEY_NOT_FOUND;
+            errMsg = tr(ERR_KEY_NOT_FOUND);
             break;
         case YK_EFIRMWARE:
-            errMsg = ERR_FIRMWARE_NOT_SUPPORTED;
+            errMsg = tr(ERR_FIRMWARE_NOT_SUPPORTED);
             break;
         default:
             if(chalresp) {
-                errMsg = ERR_PROCESSING_CHALRESP;
+                errMsg = tr(ERR_PROCESSING_CHALRESP);
             } else {
-                errMsg = ERR_PROCESSING;
+                errMsg = tr(ERR_PROCESSING);
             }
             break;
         }
